<?php

/**
 * Content width
 */

if ( ! isset( $content_width ) )
	$content_width = 1140;

/**
 * Theme setup
 */

add_action( 'after_setup_theme', 'tz_theme_setup' );
function tz_theme_setup() {
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Title tag
	add_theme_support( 'title-tag' );

	// Register WP 3.0+ Menus
	register_nav_menus( array( 'primary-menu' => 'Primary Menu' ) );

	// Post thumbnail support
	add_theme_support( 'post-thumbnails' );

	// Add custom post thumbnail sizes
	add_image_size( 'tz_home_intro', 1000, 500, true );
	add_image_size( 'tz_home_house', 300, 300, true );
}

/**
 * Adding custom image sizes to media uploader
 */

add_filter( 'image_size_names_choose', 'tz_image_sizes' );
function tz_image_sizes( $sizes ) {
	$add_sizes = array(
		"tz_home_intro" => 'Home intro'
	);
	$new_sizes = array_merge( $sizes, $add_sizes );

	return $new_sizes;
}

/**
 * Get image
 */

function tz_get_image( $post_id, $size, $id = false ) {
	$post = get_children(
		array(
			'post_parent' => $post_id,
			'post_type'   => 'attachment',
			'numberposts' => 1
		)
	);

	if ( $post ) {
		foreach( $post as $p ) {
			$attachment_id = $p->ID;
			$attachment = wp_get_attachment_image_src( $attachment_id, $size );
		}

		if ( isset( $attachment ) && $attachment ) {
			if ( $id )
				return $attachment_id;

			return $attachment[0];
		}
	}
}

/**
 * Load styles
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_styles' );
function tz_enqueue_styles() {
  //wp_enqueue_style( 'tz-gf', 'http://fonts.googleapis.com/css?family=Titillium+Web:200,300,400,700', false );
	wp_enqueue_style( 'tz-style', get_stylesheet_uri() );
	wp_enqueue_style( 'tz-fa', get_template_directory_uri() . '/assets/fonts/font-awesome.min.css' );
}

/**
 * Load scripts
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_scripts' );
function tz_enqueue_scripts() {
	wp_register_script( 'jquery-min', get_template_directory_uri() . '/assets/scripts/jquery-1.11.1.min.js', 'jquery', '1.11.1', TRUE );
	wp_register_script( 'plugins', get_template_directory_uri() . '/assets/scripts/plugins.js', 'jquery', '0.0.1', TRUE );
	wp_register_script( 'app', get_template_directory_uri() . '/assets/scripts/app.js', 'jquery', '0.0.1', TRUE );

	wp_enqueue_script( 'jquery-min' );
	wp_enqueue_script( 'plugins' );
	wp_enqueue_script( 'app' );

	if ( is_single() )
		wp_enqueue_script( 'comment-reply' );

	wp_localize_script( 'app', 'tz', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
}

/**
 * Filter search results
 */

add_filter( 'pre_get_posts', 'tz_search_filter' );
function tz_search_filter( $query ) {
	if ( $query->is_search )
		$query->set( 'post_type', 'post' );

	return $query;
}

/**
 * Pagination
 */

function tz_pagination( $range = 2 ) {
	global $wp_query, $paged;

	$showitems = ( $range * 2 ) + 1;
	$paged = ( empty( $paged ) ) ? 1 : $paged;
	$pages = ( ! $wp_query->max_num_pages ) ? 1 : $wp_query->max_num_pages;

    if ( $pages != 1 ) {
		echo '<nav class="pagination clearfix">';

		if ( $paged > 1 ) {
			echo '<a class="previous" href="' . get_pagenum_link( $paged - 1 ) . '">&larr; Previous</a>';
		}

		for ( $i = 1; $i <= $pages; $i++ ) {
			if ( $pages != 1 && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged == $i ) ? '<span class="current">' . $i . '</span>' : '<a href="' . get_pagenum_link( $i ) . '">' . $i . '</a>';
			}
		}

		if ( $paged < $pages ) {
			echo '<a class="next" href="' . get_pagenum_link( $paged + 1 ) . '">Next &rarr;</a>';
		}

        echo '</nav>' . "\n";
     }
}

/**
 * Contact Form
 */

add_action( 'wp_ajax_nopriv_tz_contact_form', 'tz_ajax_contact_form' );
add_action( 'wp_ajax_tz_contact_form', 'tz_ajax_contact_form' );
function tz_ajax_contact_form() {
	$params = array();

	parse_str( $_POST['data'], $params );

	$name = trim( $params['name'] );
	$email = $params['email'];
	$phone = $params['phone'];
	$street = $params['street'];
	$city = $params['city'];
	$subject = $params['subject'];
	$admin_email = ( get_theme_mod( 'tz_contact_email' ) ) ? get_theme_mod( 'tz_contact_email' ) : get_option( 'admin_email' );

	if ( $subject == "" )
		$subject = 'A message from contact form at ' . get_bloginfo( 'name' );

	if ( $name == "" )
		$error['name'] = '<div class="message error">Please enter your name</div>';

	if ( ! is_email( trim( $email ) ) )
		$error['email'] = '<div class="message error">Your email is invalid</div>';

	if ( $phone == "" )
		$error['phone'] = '<div class="message error">Please enter your phone</div>';

	if ( $street == "" )
		$error['street'] = '<div class="message error">Please enter your street address</div>';

	if ( $city == "" )
		$error['city'] = '<div class="message error">Please enter your city</div>';

	if ( ! isset( $error ) ) {
		$body = 'Name: ' . $name . "\n\n";
		$body.= 'Email: ' . $email . "\n\n";
		$body.= 'Phone: ' . $phone . "\n\n";
		$body.= 'Street: ' . $street . "\n\n";
		$body.= 'City: ' . $city . "\n\n";
		$headers = 'From: ' . $name . ' <' . $email . '>' . "\r\n";
		$headers.= 'Reply-To: ' . $email;
		wp_mail( $admin_email, $subject, $body, $headers );
		$success['success'] = '<div class="message success">Thank you! Your message will be replied soon.</div>';
		echo json_encode( $success );
	} else {
		echo json_encode( $error );
	}

	exit();
}

/**
 * Custom body class
 */

add_filter( 'body_class', 'custom_body_class' );
function custom_body_class( $classes ) {
	if ( is_home() || is_front_page() ) {
		$classes[] = 'homepage';
	}

	return $classes;
}

/**
 * Add class to link nav
 */

 add_filter( 'next_posts_link_attributes', 'posts_link_attributes' );
 add_filter( 'previous_posts_link_attributes', 'posts_link_attributes' );
 function posts_link_attributes() {
     return 'class="button"';
 }

 /**
  * Comment nav
  */

function tz_comment_nav() {
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) {
?>
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'realestate' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'realestate' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'realestate' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
<?php
	}
}

/**
 * Include some files
 */

require( 'functions/customizer.php' );
require( 'functions/customizer-textarea.php' );
require( 'functions/customizer-pages.php' );
require( 'functions/metaboxes.php' );
require( 'includes/meta/house.php' );
